# Examples

We provide example notebooks to model combinatorial optimization problems using DIDPPy.

- [Knapsack problem](./knapsack.ipynb) [![Open In Colab](https://colab.research.google.com/assets/colab-badge.svg)](https://colab.research.google.com/github/domain-independent-dp/didp-rs/blob/main/didppy/examples/knapsack.ipynb)
- [Traveling salesperson problem with time windows (TSPTW)](./tsptw.ipynb) [![Open In Colab](https://colab.research.google.com/assets/colab-badge.svg)](https://colab.research.google.com/github/domain-independent-dp/didp-rs/blob/main/didppy/examples/tsptw.ipynb)
- [Capacitated vehicle routing problem (CVRP)](./cvrp.ipynb) [![Open In Colab](https://colab.research.google.com/assets/colab-badge.svg)](https://colab.research.google.com/github/domain-independent-dp/didp-rs/blob/main/didppy/examples/cvrp.ipynb)
- [Multi-commodity pick-and-delivery traveling salesperson problem (m-PDTSP)](./m-pdtsp.ipynb) [![Open In Colab](https://colab.research.google.com/assets/colab-badge.svg)](https://colab.research.google.com/github/domain-independent-dp/didp-rs/blob/main/didppy/examples/m-pdtsp.ipynb)
- [Simple assembly line balancing problem (SALBP-1)](./salbp-1.ipynb) [![Open In Colab](https://colab.research.google.com/assets/colab-badge.svg)](https://colab.research.google.com/github/domain-independent-dp/didp-rs/blob/main/didppy/examples/salbp-1.ipynb)
- [Bin packing](./bin-packing.ipynb) [![Open In Colab](https://colab.research.google.com/assets/colab-badge.svg)](https://colab.research.google.com/github/domain-independent-dp/didp-rs/blob/main/didppy/examples/bin-packing.ipynb)
- [Minimization of open stacks problem (MOSP)](./mosp.ipynb) [![Open In Colab](https://colab.research.google.com/assets/colab-badge.svg)](https://colab.research.google.com/github/domain-independent-dp/didp-rs/blob/main/didppy/examples/mosp.ipynb)
- [Graph-clear](./graph-clear.ipynb) [![Open In Colab](https://colab.research.google.com/assets/colab-badge.svg)](https://colab.research.google.com/github/domain-independent-dp/didp-rs/blob/main/didppy/examples/graph-clear.ipynb)
- [Talent scheduling](./talent-scheduling.ipynb) [![Open In Colab](https://colab.research.google.com/assets/colab-badge.svg)](https://colab.research.google.com/github/domain-independent-dp/didp-rs/blob/main/didppy/examples/talent-scheduling.ipynb)
- [Single machine total weighted tardiness with precedence](./single-machine.ipynb) [![Open In Colab](https://colab.research.google.com/assets/colab-badge.svg)](https://colab.research.google.com/github/domain-independent-dp/didp-rs/blob/main/didppy/examples/single-machine.ipynb)
